@@ -1,14 +1,14 @@
 import re
 
 def formatcc(text_to_search):
-    ccmatches = re.search(r'(4|5|6|7)\d{15,18}\D',text_to_search)
+    ccmatches = re.search(r'(3|4|5|6|7)\d{11,18}\D',text_to_search)
     if ccmatches is not None:
             cc = ccmatches[0]
-            cc = re.search(r'(4|5|6|7)\d{15,18}',cc)
+            cc = re.search(r'(3|4|5|6|7)\d{11,18}',cc)
             cc = cc[0]
             cc_end = ccmatches.span()[1]
             #print(ccmatches.span(0))
-            text_to_search = text_to_search[cc_end:]
+            text_to_search = text_to_search[cc_end-1:]
             if cc[0] == 3:
                 pattern = re.compile(r'\d{4}')
             else:
@@ -37,3 +37,4 @@ def formatcc(text_to_search):
     else:
         return "Invalid CC Number."
 
+
